@@ -6,7 +6,7 @@ try:
     from urllib import urlencode
 except ImportError:
     from urllib.parse import urlencode
-from httplib2 import Http
+import requests
 try:
     from simplejson import loads
 except ImportError:
@@ -33,27 +33,17 @@ class LogglySession(object):
         self.protocol = secure and 'https' or 'http'
 
     def _api_help(self, endpoint, params=None, method='GET'):
-        h = Http()
-        h.add_credentials(self.username, self.password)
+        s = requests.Session()
+        s.auth = (self.username, self.password)
         url = '%s://%s.%s/%s' % (self.protocol, self.subdomain, self.domain,
                                  endpoint)
-        if method == 'GET':
-            body = ''
-            if params:
-                url += '?' + urlencode(params)
-        elif params:
+        body = ''
+        if params and method != 'GET':
             body = urlencode(params)
-        else:
-            body = ''
-        headers, results = h.request(url, method, body)
-        status = headers['status']
-        if int(status) == 401:
-            raise AuthFail('Sorry, your authentication was not accepted.')
-        # TODO check status, raise appropriate errors or something
-        try:
-            return loads(results.decode('utf-8'))
-        except ValueError:
-            return results
+            params = None
+        response = s.request(method, url, params=params, data=body, verify=True)
+        response.raise_for_status()
+        return response.json()
 
     @property
     def inputs(self):
@@ -113,9 +103,7 @@ class LogglySession(object):
             syslog 514
             HTTP
             syslog_tls.
-        JSON can only be used with HTTP inputs.'''
-        if json and service.lower() != 'http':
-            raise ValueError("only HTTP inputs can use JSON")
+        '''
         format = json and 'json' or 'text'
         params = {'name': name, 'service': service, 'description': description,
                   'format': format}
