@@ -1,5 +1,5 @@
 from functools import wraps
-from httplib2 import Http
+import requests
 
 
 def async(func):
@@ -22,9 +22,14 @@ def async(func):
     return wraps(func)(newfunc)
 
 
-def post_to_endpoint(endpoint, message):
-    h = Http()
-    h.request(endpoint, 'POST', message)
+def post_to_endpoint(endpoint, message, encoding='utf-8'):
+    # If unicode, try to encode
+    if isinstance(message, unicode):
+        try:
+            message = message.encode(encoding)
+        except UnicodeEncodeError:
+            pass
+    requests.post(endpoint, message, verify=True)
 async_post_to_endpoint = async(post_to_endpoint)
 
 
